@@ -36,24 +36,23 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
       if tag=='div':
          if dict(attrs).has_key('class'):
             if dict(attrs)['class'] == 'bg1' or dict(attrs)['class'] == 'bg3':
-               DebugLog("  self.tagDestination = True")
                self.tagDestination = True
                self.currentRide = Ride()
 
             elif dict(attrs)['class'] == 'schmsg1' or dict(attrs)['class'] == 'schmsg3':
                self.tagHeureMission = True
-            
+
             elif dict(attrs)['class'] == 'error':
                DebugLog("  Error found!")
                self.tagError = True
-               
+
          elif dict(attrs).has_key('id') and dict(attrs)['id']=='message':
             DebugLog("  Error found!")
             self.tagError = True
 
       elif self.tagHeureMission and tag == 'b':
          self.tagHeurePassageB = True
-         
+
       elif self.tagHeureMission and tag == 'a':
          self.tagTrainA = True
 
@@ -61,14 +60,14 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
       if self.tagDestination:
          u = data.replace('>', '').strip()
          self.currentRide.setDestination(u)
-         
+
       if self.tagTrainA:
          self.currentRide.setTrain(data.strip())
 
       if self.tagHeurePassageB:
          heure = data.strip()
          voie=''
-         res = re.search("(.+?)\s[^v]*V.+?(\d+)", heure)
+         res = re.search("(.+?)\s+[vV]\.?(?:oie)?\s?(\d+)", heure)
          if res:
             heure = res.group(1).strip()
             voie = res.group(2).strip()
@@ -78,7 +77,7 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
          # On raccourcit 'Train a l'approche' et 'Train a quai'
          heure = heure.replace('Train ', '')
          self.currentRide.setHeure(heure)
-         
+
       if self.tagError:
          if not self.currentRide:
             self.currentRide = Ride()
@@ -91,11 +90,11 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
          self.tagHeurePassageB = False
          self.listRides.append(self.currentRide)
          self.currentRide = None
-   
+
       if self.tagError:
          self.listRides.append(self.currentRide)
          self.currentRide = None
-      
+
       self.tagDestination ^= (self.tagDestination and tag=='div')
       self.tagTrainA ^= (self.tagTrainA and tag=='a')
       self.tagHeureMission ^= (self.tagHeureMission and tag=='div')
@@ -104,18 +103,26 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
    def fillModel(self, imax):
       DebugLog("TableParserRERratp::fillModel(%s)"%self.id)
       if self.sens!='A' and self.sens!='R':
-         self.rideModel.SetInfo('ERROR', 'Sens du trajet indfini: "%s"'%self.sens)
-      
+         self.rideModel.SetInfo('ERROR', 'Sens du trajet indéfini: "%s"'%self.sens)
+
       self.AppendRidesToModel(imax)
       return self.perturbation, self.error
 
    def ParsePerturbation(self, str):
       DebugLog("TableParserTransilien::ParsePerturbation")
+      self.rideModel.ClearPerturbations()
 
       res = re.findall('<div class="trafic">(.+?)</div>', str, re.DOTALL)
       if res:
-         for perturbation in res:
-            p = re.sub('<.+?>', '',perturbation).strip().replace('&#39;', "'")
+         for p in res:
+#            r = re.match('alt=" %s".+?>(.+?)(<.+?alt=.+?)?(Trafic normal.+)?', p)
+            r = re.search('alt=" %s".+?>.+?<b>.+?</b>(.+?)(<img.+?alt="RER".+>)'%self.ligne, p, re.DOTALL)
+            if not r:
+               continue
+            p=r.group(1)
+            p=p.replace('\n',' ').replace('<br>', '\n')
+            p=re.sub('\s+', ' ', p)
+            p = re.sub('<.+?>', '', p).strip().replace('&#39;', "'")
             if p.find('Trafic normal')==-1:
                self.rideModel.AddPerturbation( unicode(p, 'utf-8') )
 
@@ -132,7 +139,7 @@ class ExtractorRERratp(TableParserRERratp):
       lineTitle = ( ('R', self.ligne, 32), self.depart)
       self.rideModel.setIconTitle( lineTitle )
 
-      #urlMobi = 'http://www.ratp.fr/horaires/fr/ratp/rer/prochains_passages/R%s/%s/%s'
+      self.urlPerturb = 'http://www.ratp.fr/informer/trafic/trafic.php?cat=2'
       urlMobi = 'http://wap.ratp.fr/siv/schedule?service=next&reseau=rer&lineid=R%s&directionsens=%s&stationid=%s'
       self.url = urlMobi%(self.ligne, self.sens, self.station)
       DebugLog(self.url)
