@@ -168,6 +168,15 @@ class AddRideDlg(QtGui.QDialog ):
    def WriteConfig(self):
       self.garesConf.WriteRides()
 
+   def IsRATPcode(self, val):
+      try:
+         if int(val)>0:
+            return True
+         else:
+            return False
+      except:
+         return False
+
    def AddTrajet(self, depart, arrivee):
       if not depart:
          raise RuntimeError("Gare de départ non renseignée")
@@ -175,7 +184,7 @@ class AddRideDlg(QtGui.QDialog ):
       if not arrivee:
          raise RuntimeError("Gare d'arrivée non renseignée")
 
-      c = self.db.execute("SELECT ligne, exploitant FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid" % depart)
+      c = self.db.execute("SELECT ligne FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid" % depart)
       lignesD=[]
       for row in c:
          lignesD.append(row[0])
@@ -184,33 +193,45 @@ class AddRideDlg(QtGui.QDialog ):
          DebugLog("Gare '%s' inconnue"%depart)
          raise RuntimeError("Gare '%s' inconnue"%depart)
 
-      c = self.db.execute("SELECT ligne, exploitant FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid" % arrivee)
+      c = self.db.execute("SELECT ligne FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid" % arrivee)
 
       lignesA=[]
       for row in c:
          if row[0] in lignesD:
             ligne=row[0]
-            lignesA.append(ligne)
-            DebugLog("commun : "+ligne)
-            break
+            if ligne not in lignesA:
+               lignesA.append(ligne)
+               DebugLog("commun : "+ligne)
 
       if len(lignesA)==0:
          DebugLog("Gare '%s' inconnue"%arrivee)
          raise RuntimeError("Gare '%s' inconnue"%arrivee)
+      elif len(lignesA)>1:
+         print 'plusieurs lignes'
 
       DebugLog(str(lignesA))
+      
       req="SELECT name, code, exploitant, position FROM gares, lignes WHERE gares.name='%s' AND gares.rowid=lignes.gareid AND ligne='%s'" % (depart, ligne)
       DebugLog(req)
       c = self.db.execute(req)
-      
+
       res = c.fetchone()
       if not res:
          return False
 
-      DebugLog(str(res))         
-      for res in c:
-         DebugLog(str(res))
-      
+      codeDepart = res[1]
+      exploitantD = res[2]
+
+      DebugLog(str(res))
+
+      if exploitantD=='R' and not self.IsRATPcode(codeDepart):
+         for res in c:
+            DebugLog(str(res))
+            if self.IsRATPcode(res[1])>0:
+               codeDepart = res[1]
+            else:
+               DebugLog("%s not RATP code"%res[1])
+
       tec = ''
       if ligne[0]=='M':
          tec = 'Metro'
@@ -222,8 +243,6 @@ class AddRideDlg(QtGui.QDialog ):
          raise RuntimeError('tec inconnu "%s"'%ligne)
 
       depart = res[0]
-      codeDepart = res[1]
-      exploitantD = res[2]
       posDepart = 0
       posArrivee = 0
 
@@ -234,15 +253,26 @@ class AddRideDlg(QtGui.QDialog ):
       DebugLog(req)
       c = self.db.execute(req)
       res = c.fetchone()
-      
+
       DebugLog(str(res))
-      for res in c:
-         DebugLog(str(res))
+      codeArrivee = res[1]
+      exploitantA = res[2]
+
+      if exploitantA!=exploitantD or \
+         (exploitantA=='R' and not self.IsRATPcode(codeArrivee)):
+         for res in c:
+            DebugLog(str(res))
+            if self.IsRATPcode(res[1]):
+               if exploitantD=='R':
+                  DebugLog(' exploitantD==R %s'%res[1])
+                  codeArrivee = res[1]
+            else:
+               if exploitantD=='S':
+                  DebugLog('exploitantD==S %s'%res[1])
+                  codeArrivee = res[1]
 
       ligne = ligne[1:]
       arrivee = res[0]
-      codeArrivee = res[1]
-      exploitantA = res[2]
       if res[3]:
          posArrivee = int(res[3])
 
@@ -255,7 +285,7 @@ class AddRideDlg(QtGui.QDialog ):
 
       DebugLog('posD=%d, posA=%d, dir=%s'%(posDepart, posArrivee, direction))
 
-      l = Ride(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitantA, direction)
+      l = Ride(ligne, tec, depart, arrivee, codeDepart, codeArrivee, exploitantD, direction)
       self.garesConf.AddRide(l)
       return l
 
